@@ -39,6 +39,10 @@ package Log::Fine::Handle::Console;
 
 use base qw( Log::Fine::Handle );
 
+use Log::Fine;
+
+our $VERSION = $Log::Fine::Handle::VERSION;
+
 =head1 METHODS
 
 =head2 msgWrite
@@ -140,7 +144,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: 0c2e24988059c23847668363bbf65cf1cd1a9eeb $
+  $Id: e58ed890fed29e5676314e8a4083fc4fa7dec728 $
 
 =head1 COPYRIGHT & LICENSE
 
