@@ -58,6 +58,9 @@ use warnings;
 package Log::Fine::Levels;
 
 use Carp;
+use Log::Fine;
+
+our $VERSION = $Log::Fine::VERSION;
 
 # Constants
 # --------------------------------------------------------------------
@@ -327,7 +330,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: Levels.pm 241 2010-05-10 20:50:51Z cfuhrman $
+  $Id: 0a2980e135fbe97a86a23b0309ed8eea79ce4403 $
 
 =head1 COPYRIGHT & LICENSE
 
